@@ -13,11 +13,6 @@ import copy
 import logging
 import mrcfile
 import numpy
-
-# import pandas
-import scipy.stats
-
-# import time
 import warnings
 import parakeet.config
 import parakeet.dqe
@@ -25,7 +20,6 @@ import parakeet.freeze
 import parakeet.futures
 import parakeet.inelastic
 import parakeet.sample
-import warnings
 from math import sqrt, pi, sin, floor
 from collections.abc import Iterable
 from scipy.spatial.transform import Rotation
@@ -391,7 +385,7 @@ class ProjectedPotentialSimulator(object):
         # Create the sample extractor
         x0 = (-offset, -offset)
         x1 = (x_fov + offset, y_fov + offset)
-        thickness = self.simulation["division_thickness"]
+        # thickness = self.simulation["division_thickness"]
         # extractor = parakeet.sample.AtomSliceExtractor(
         #     sample=self.sample,
         #     translation=position,
@@ -465,10 +459,9 @@ class ProjectedPotentialSimulator(object):
         # Get the potential and thickness
         volume_z0 = self.sample.shape_box[0][2]
         volume_z1 = self.sample.shape_box[1][2]
-        zsize = int(floor(volume_z1 - volume_z0))
         slice_thickness = self.simulation["slice_thickness"]
+        zsize = int(floor((volume_z1 - volume_z0) / slice_thickness))
         handle = mrcfile.new("projected_potential_%d.mrc" % index, overwrite=True)
-        handle.voxel_size = (pixel_size, pixel_size, slice_thickness)
         potential = numpy.zeros(shape=(zsize, ny, nx), dtype="float32")
         # thickness = handle.create_dataset(
         #     "thickness", (0,), dtype="float32", maxshape=(None,)
@@ -485,14 +478,13 @@ class ProjectedPotentialSimulator(object):
                 "Calculating potential for slice: %.2f -> %.2f (index: %d)"
                 % (z0, z1, index)
             )
-            potential[index, :, :] = V[margin:-margin, margin:-margin]
+            potential[index, :, :] = V[margin:-margin, margin:-margin].T
 
         # Run the simulation
-        output_multislice = multem.compute_projected_potential(
-            system_conf, input_multislice, callback
-        )
+        multem.compute_projected_potential(system_conf, input_multislice, callback)
 
         handle.set_data(potential)
+        handle.voxel_size = tuple((pixel_size, pixel_size, slice_thickness))
 
         # Compute the image scaled with Poisson noise
         return (index, angle, position, None, None)
@@ -547,6 +539,25 @@ class ExitWaveImageSimulator(object):
                     0, self.microscope.beam.drift["magnitude"], size=2
                 )
                 logger.info("Adding drift of %f, %f " % (shiftx, shifty))
+            elif self.microscope.beam.drift["type"] == "random_smoothed":
+                if index == 0:
+
+                    def generate_smoothed_random(magnitude, num_images):
+                        shift = numpy.random.normal(0, magnitude, size=(num_images, 2))
+                        shiftx = numpy.convolve(
+                            shift[:, 0], numpy.ones(5) / 5, mode="same"
+                        )
+                        shifty = numpy.convolve(
+                            shift[:, 1], numpy.ones(5) / 5, mode="same"
+                        )
+                        return shiftx, shifty
+
+                    self.shift = generate_smoothed_random(
+                        self.microscope.beam.drift["magnitude"], len(self.scan)
+                    )
+                shiftx = self.shift[0][index]
+                shifty = self.shift[1][index]
+                logger.info("Adding drift of %f, %f " % (shiftx, shifty))
             elif self.microscope.beam.drift["type"] == "sinusoidal":
                 shiftx = sin(angle * pi / 180) * self.microscope.beam.drift["magnitude"]
                 shifty = shiftx
@@ -567,7 +578,7 @@ class ExitWaveImageSimulator(object):
         x_fov = nx * pixel_size
         y_fov = ny * pixel_size
         margin_offset = margin * pixel_size
-        padding_offset = padding * pixel_size
+        # padding_offset = padding * pixel_size
         offset = (padding + margin) * pixel_size
 
         # Set the rotation angle
@@ -579,7 +590,7 @@ class ExitWaveImageSimulator(object):
         x1 = numpy.array((x_fov + margin_offset, position + y_fov + margin_offset))
         x0 += origin
         x1 += origin
-        thickness = self.simulation["division_thickness"]
+        # thickness = self.simulation["division_thickness"]
         # extractor = parakeet.sample.AtomSliceExtractor(
         #    sample=self.sample,
         #    translation=position,
@@ -611,173 +622,172 @@ class ExitWaveImageSimulator(object):
 
         # Compute the B factor
         if self.simulation["radiation_damage_model"]:
-            sigma_B = sqrt(
-                self.simulation["sensitivity_coefficient"]
-                * self.microscope.beam.electrons_per_angstrom
-                * (index + 1)
+            input_multislice.static_B_factor = (
+                8
+                * pi ** 2
+                * (
+                    self.simulation["sensitivity_coefficient"]
+                    * self.microscope.beam.electrons_per_angstrom
+                    * (index + 1)
+                )
             )
         else:
-            sigma_B = 0
+            input_multislice.static_B_factor = 0
 
         # Either slice or don't
-        if True:  # len(extractor) == 1:
+        # if True:  # len(extractor) == 1:
 
-            # Set the atoms in the input after translating them for the offset
-            # zslice = extractor[0]
-            atoms = self.sample.get_atoms_in_fov(x0, x1)
-            logger.info("Simulating with %d atoms" % atoms.data.shape[0])
-            # logger.info(
-            #     "    Simulating z slice %f -> %f with %d atoms"
-            #     % (zslice.x_min[2], zslice.x_max[2], zslice.atoms.data.shape[0])
-            # )
+        # Set the atoms in the input after translating them for the offset
+        # zslice = extractor[0]
+        atoms = self.sample.get_atoms_in_fov(x0, x1)
+        logger.info("Simulating with %d atoms" % atoms.data.shape[0])
+        # logger.info(
+        #     "    Simulating z slice %f -> %f with %d atoms"
+        #     % (zslice.x_min[2], zslice.x_max[2], zslice.atoms.data.shape[0])
+        # )
 
-            # Set atom sigma
-            atoms.data["sigma"] = sigma_B
+        # Set atom sigma
+        # atoms.data["sigma"] = sigma_B
 
-            if len(atoms.data) > 0:
-                coords = atoms.data[["x", "y", "z"]].to_numpy()
-                coords = (
-                    Rotation.from_rotvec((0, angle * pi / 180, 0)).apply(
-                        coords - self.sample.centre
-                    )
-                    + self.sample.centre
-                    - (shiftx, shifty + position, 0)
-                ).astype("float32")
-                atoms.data["x"] = coords[:, 0]
-                atoms.data["y"] = coords[:, 1]
-                atoms.data["z"] = coords[:, 2]
-            # atoms.data = atoms.data.append(parakeet.sample.AtomData(atomic_number=[1,1], x=[750,750], y=[750,750], z=[0,4000],sigma=[0,0],occupancy=[1,1],charge=[0,0]).data)
+        if len(atoms.data) > 0:
+            coords = atoms.data[["x", "y", "z"]].to_numpy()
+            coords = (
+                Rotation.from_rotvec((0, angle * pi / 180, 0)).apply(
+                    coords - self.sample.centre
+                )
+                + self.sample.centre
+                - (shiftx, shifty + position, 0)
+            ).astype("float32")
+            atoms.data["x"] = coords[:, 0]
+            atoms.data["y"] = coords[:, 1]
+            atoms.data["z"] = coords[:, 2]
 
-            input_multislice.spec_atoms = atoms.translate(
-                (offset - origin[0], offset - origin[1], 0)
-            ).to_multem()
-            logger.info("   Got spec atoms")
+        input_multislice.spec_atoms = atoms.translate(
+            (offset - origin[0], offset - origin[1], 0)
+        ).to_multem()
+        logger.info("   Got spec atoms")
 
-            if self.simulation["ice"] == True:
+        if self.simulation["ice"] == True:
 
-                # Create the masker
-                masker = multem.Masker(
-                    input_multislice.nx, input_multislice.ny, pixel_size
+            # Create the masker
+            masker = multem.Masker(input_multislice.nx, input_multislice.ny, pixel_size)
+
+            # Get the sample centre
+            shape = self.sample.shape
+            centre = self.sample.centre
+            centre = (
+                centre[0] + offset - shiftx - origin[0],
+                centre[1] + offset - shifty - position - origin[1],
+                centre[2],
+            )
+
+            # Set the shape
+            if shape["type"] == "cube":
+                length = shape["cube"]["length"]
+                masker.set_cuboid(
+                    (
+                        centre[0] - length / 2,
+                        centre[1] - length / 2,
+                        centre[2] - length / 2,
+                    ),
+                    (length, length, length),
+                )
+            elif shape["type"] == "cuboid":
+                length_x = shape["cuboid"]["length_x"]
+                length_y = shape["cuboid"]["length_y"]
+                length_z = shape["cuboid"]["length_z"]
+                masker.set_cuboid(
+                    (
+                        centre[0] - length_x / 2,
+                        centre[1] - length_y / 2,
+                        centre[2] - length_z / 2,
+                    ),
+                    (length_x, length_y, length_z),
+                )
+            elif shape["type"] == "cylinder":
+                radius = shape["cylinder"]["radius"]
+                if not isinstance(radius, Iterable):
+                    radius = [radius]
+                length = shape["cylinder"]["length"]
+                offset_x = shape["cylinder"].get("offset_x", [0] * len(radius))
+                offset_z = shape["cylinder"].get("offset_z", [0] * len(radius))
+                axis = shape["cylinder"].get("axis", (0, 1, 0))
+                masker.set_cylinder(
+                    (centre[0], centre[1] - length / 2, centre[2]),
+                    axis,
+                    length,
+                    list(radius),
+                    list(offset_x),
+                    list(offset_z),
                 )
 
-                # Get the sample centre
-                shape = self.sample.shape
-                centre = self.sample.centre
-                centre = (
-                    centre[0] + offset - shiftx - origin[0],
-                    centre[1] + offset - shifty - position - origin[1],
-                    centre[2],
-                )
-
-                # Set the shape
-                if shape["type"] == "cube":
-                    length = shape["cube"]["length"]
-                    masker.set_cuboid(
-                        (
-                            centre[0] - length / 2,
-                            centre[1] - length / 2,
-                            centre[2] - length / 2,
-                        ),
-                        (length, length, length),
-                    )
-                elif shape["type"] == "cuboid":
-                    length_x = shape["cuboid"]["length_x"]
-                    length_y = shape["cuboid"]["length_y"]
-                    length_z = shape["cuboid"]["length_z"]
-                    masker.set_cuboid(
-                        (
-                            centre[0] - length_x / 2,
-                            centre[1] - length_y / 2,
-                            centre[2] - length_z / 2,
-                        ),
-                        (length_x, length_y, length_z),
-                    )
-                elif shape["type"] == "cylinder":
-                    radius = shape["cylinder"]["radius"]
-                    if not isinstance(radius, Iterable):
-                        radius = [radius]
-                    length = shape["cylinder"]["length"]
-                    offset_x = shape["cylinder"].get("offset_x", [0] * len(radius))
-                    offset_z = shape["cylinder"].get("offset_z", [0] * len(radius))
-                    axis = shape["cylinder"].get("axis", (0, 1, 0))
-                    masker.set_cylinder(
-                        (centre[0], centre[1] - length / 2, centre[2]),
-                        axis,
-                        length,
-                        list(radius),
-                        list(offset_x),
-                        list(offset_z),
-                    )
-
-                # Rotate
-                origin = centre
-                masker.set_rotation(origin, (0, angle * pi / 180.0, 0))
-
-                # Run the simulation
-                output_multislice = multem.simulate(
-                    system_conf, input_multislice, masker
-                )
-
-            else:
-
-                # Run the simulation
-                logger.info("Simulating")
-                output_multislice = multem.simulate(system_conf, input_multislice)
-
-        else:
-            pass
-            # # Slice the specimen atoms
-            # def slice_generator(extractor):
-
-            #     # Get the data from the data buffer and return
-            #     def prepare(data_buffer):
-
-            #         # Extract the data
-            #         atoms = parakeet.sample.AtomData(
-            #             data=pandas.concat([d.atoms.data for d in data_buffer])
-            #         )
-            #         z_min = min([d.x_min[2] for d in data_buffer])
-            #         z_max = max([d.x_max[2] for d in data_buffer])
-            #         assert z_min < z_max
-
-            #         # Print some info
-            #         logger.info(
-            #             "    Simulating z slice %f -> %f with %d atoms"
-            #             % (z_min, z_max, atoms.data.shape[0])
-            #         )
-
-            #         # Cast the atoms
-            #         atoms = atoms.translate((offset, offset, 0)).to_multem()
-
-            #         # Return the Z-min, Z-max and atoms
-            #         return (z_min, z_max, atoms)
-
-            #     # Loop through the slices and gather atoms until we have more
-            #     # than the maximum buffer size. There seems to be an overhead
-            #     # to the simulation code so it's better to have as many atoms
-            #     # as possible before calling. Doing this is much fast than
-            #     # simulating with only a small number of atoms.
-            #     max_buffer = 10_000_000
-            #     data_buffer = []
-            #     for zslice in extractor:
-            #         data_buffer.append(zslice)
-            #         if sum(d.atoms.data.shape[0] for d in data_buffer) > max_buffer:
-            #             yield prepare(data_buffer)
-            #             data_buffer = []
-
-            #     # Simulate from the final buffer
-            #     if len(data_buffer) > 0:
-            #         yield prepare(data_buffer)
-            #         data_buffer = []
+            # Rotate
+            origin = centre
+            masker.set_rotation(origin, (0, angle * pi / 180.0, 0))
 
             # Run the simulation
-            # st = time.time()
-            # output_multislice = multem.simulate(
-            #     system_conf, input_multislice, slice_generator(extractor)
-            # )
-            # logger.info(
-            #     "    Image %d simulated in %d seconds" % (index, time.time() - st)
-            # )
+            output_multislice = multem.simulate(system_conf, input_multislice, masker)
+
+        else:
+
+            # Run the simulation
+            logger.info("Simulating")
+            output_multislice = multem.simulate(system_conf, input_multislice)
+
+        # else:
+        #     pass
+        # # Slice the specimen atoms
+        # def slice_generator(extractor):
+
+        #     # Get the data from the data buffer and return
+        #     def prepare(data_buffer):
+
+        #         # Extract the data
+        #         atoms = parakeet.sample.AtomData(
+        #             data=pandas.concat([d.atoms.data for d in data_buffer])
+        #         )
+        #         z_min = min([d.x_min[2] for d in data_buffer])
+        #         z_max = max([d.x_max[2] for d in data_buffer])
+        #         assert z_min < z_max
+
+        #         # Print some info
+        #         logger.info(
+        #             "    Simulating z slice %f -> %f with %d atoms"
+        #             % (z_min, z_max, atoms.data.shape[0])
+        #         )
+
+        #         # Cast the atoms
+        #         atoms = atoms.translate((offset, offset, 0)).to_multem()
+
+        #         # Return the Z-min, Z-max and atoms
+        #         return (z_min, z_max, atoms)
+
+        #     # Loop through the slices and gather atoms until we have more
+        #     # than the maximum buffer size. There seems to be an overhead
+        #     # to the simulation code so it's better to have as many atoms
+        #     # as possible before calling. Doing this is much fast than
+        #     # simulating with only a small number of atoms.
+        #     max_buffer = 10_000_000
+        #     data_buffer = []
+        #     for zslice in extractor:
+        #         data_buffer.append(zslice)
+        #         if sum(d.atoms.data.shape[0] for d in data_buffer) > max_buffer:
+        #             yield prepare(data_buffer)
+        #             data_buffer = []
+
+        #     # Simulate from the final buffer
+        #     if len(data_buffer) > 0:
+        #         yield prepare(data_buffer)
+        #         data_buffer = []
+
+        # Run the simulation
+        # st = time.time()
+        # output_multislice = multem.simulate(
+        #     system_conf, input_multislice, slice_generator(extractor)
+        # )
+        # logger.info(
+        #     "    Image %d simulated in %d seconds" % (index, time.time() - st)
+        # )
 
         # Get the ideal image data
         # Multem outputs data in column major format. In C++ and Python we
@@ -854,20 +864,20 @@ class OpticsImageSimulator(object):
             ctf = numpy.array(multem.compute_ctf(system_conf, input_multislice)).T
 
             # Compute the B factor for radiation damage
-            if simulation["radiation_damage_model"]:
-                sigma_B = sqrt(
-                    simulation["sensitivity_coefficient"]
-                    * microscope.beam.electrons_per_angstrom
-                    * (index + 1)
-                )
-                pixel_size = microscope.detector.pixel_size
-                Y, X = numpy.mgrid[0 : ctf.shape[0], 0 : ctf.shape[1]]
-                X = (X - ctf.shape[1] // 2) / (pixel_size * ctf.shape[1])
-                Y = (Y - ctf.shape[0] // 2) / (pixel_size * ctf.shape[0])
-                q = numpy.sqrt(X ** 2 + Y ** 2)
-                b_factor_blur = numpy.exp(-2 * pi ** 2 * q ** 2 * sigma_B ** 2)
-                b_factor_blur = numpy.fft.fftshift(b_factor_blur)
-                ctf = ctf * b_factor_blur
+            # if simulation["radiation_damage_model"]:
+            #    sigma_B = sqrt(
+            #        simulation["sensitivity_coefficient"]
+            #        * microscope.beam.electrons_per_angstrom
+            #        * (index + 1)
+            #    )
+            #    pixel_size = microscope.detector.pixel_size
+            #    Y, X = numpy.mgrid[0 : ctf.shape[0], 0 : ctf.shape[1]]
+            #    X = (X - ctf.shape[1] // 2) / (pixel_size * ctf.shape[1])
+            #    Y = (Y - ctf.shape[0] // 2) / (pixel_size * ctf.shape[0])
+            #    q = numpy.sqrt(X ** 2 + Y ** 2)
+            #    b_factor_blur = numpy.exp(-2 * pi ** 2 * q ** 2 * sigma_B ** 2)
+            #    b_factor_blur = numpy.fft.fftshift(b_factor_blur)
+            #    ctf = ctf * b_factor_blur
 
             # Compute and apply the CTF
             psi = numpy.fft.ifft2(numpy.fft.fft2(psi) * ctf)
@@ -927,56 +937,47 @@ class OpticsImageSimulator(object):
         elif self.simulation["inelastic_model"] == "mp_loss":
 
             # Set the filter width
-            filter_width = self.simulation["mp_loss_width"]
+            filter_width = self.simulation["mp_loss_width"]  # eV
 
             # Compute the energy and spread of the plasmon peak
+            thickness = parakeet.inelastic.effective_thickness(shape, angle)  # A
             peak, sigma = parakeet.inelastic.most_probable_loss(
                 microscope.beam.energy, shape, angle
-            )
-            if filter_width is not None:
-                normal = scipy.stats.norm(loc=0, scale=sigma)
-                inelastic_fraction = normal.cdf(filter_width) - normal.cdf(
-                    -filter_width
-                )
-                sigma = scipy.stats.truncnorm.std(
-                    -filter_width / 2, filter_width / 2, loc=0, scale=sigma
-                )
-            else:
-                inelastic_fraction = 1.0
-            peak /= 1000.0
-            peak = min(peak, microscope.beam.energy * 0.1)
-            spread = sigma / (microscope.beam.energy * 1000)
+            )  # eV
 
-            # Add the energy loss
-            microscope.beam.energy -= peak
+            # Save the energy and energy spread
+            beam_energy = microscope.beam.energy * 1000  # eV
+            beam_energy_spread = microscope.beam.energy_spread  # dE / E
+            beam_energy_sigma = (1.0 / sqrt(2)) * beam_energy_spread * beam_energy  # eV
 
-            # Compute the energy spread of the plasmon peak
-            microscope.beam.energy_spread += spread
-            print("Energy: %f keV" % microscope.beam.energy)
-            print("Energy spread: %f ppm" % microscope.beam.energy_spread)
-            print("Inelastic fraction: % f" % inelastic_fraction)
+            # Set a maximum peak energy loss
+            peak = min(peak, beam_energy * 0.1)  # eV
 
-            # Calculate the image
-            image = compute_image(
-                psi, microscope, self.simulation, x_fov, y_fov, offset, self.device
+            # Make optimizer
+            optimizer = parakeet.inelastic.EnergyFilterOptimizer(dE_min=-60, dE_max=200)
+            assert self.simulation["mp_loss_position"] in ["peak", "optimal"]
+            if self.simulation["mp_loss_position"] != "peak":
+                peak = optimizer(beam_energy, thickness, filter_width=filter_width)
+
+            # Compute elastic fraction and spread
+            elastic_fraction, elastic_spread = optimizer.compute_elastic_component(
+                beam_energy, thickness, peak, filter_width
             )
 
-            # Compute the fraction of electrons in the plasmon peak
-            electron_fraction = parakeet.inelastic.mp_loss_fraction(shape, angle)
-            electron_fraction *= inelastic_fraction
-
-            # Scale the image by the fraction of electrons
-            image *= electron_fraction
-
-        elif self.simulation["inelastic_model"] == "unfiltered":
-
-            # Compute the energy and spread of the plasmon peak
-            peak, sigma = parakeet.inelastic.most_probable_loss(
-                microscope.beam.energy, shape, angle
+            # Compute inelastic fraction and spread
+            (
+                inelastic_fraction,
+                inelastic_spread,
+            ) = optimizer.compute_inelastic_component(
+                beam_energy, thickness, peak, filter_width
             )
-            peak /= 1000.0
-            peak = min(peak, microscope.beam.energy * 0.1)
-            spread = sigma / (microscope.beam.energy * 1000)
+
+            # Compute the spread
+            elastic_spread = elastic_spread / beam_energy  # dE / E
+            inelastic_spread = inelastic_spread / beam_energy  # dE / E
+
+            # Set the spread for the zero loss image
+            microscope.beam.energy_spread = elastic_spread  # dE / E
 
             # Compute the zero loss image
             image1 = compute_image(
@@ -984,10 +985,45 @@ class OpticsImageSimulator(object):
             )
 
             # Add the energy loss
-            microscope.beam.energy -= peak
+            microscope.beam.energy = (beam_energy - peak) / 1000.0  # keV
 
             # Compute the energy spread of the plasmon peak
-            microscope.beam.energy_spread += spread
+            microscope.beam.energy_spread = (
+                beam_energy_spread + inelastic_spread
+            )  # dE / E
+            print("Energy: %f keV" % microscope.beam.energy)
+            print("Energy spread: %f ppm" % microscope.beam.energy_spread)
+
+            # Compute the MPL image
+            image2 = compute_image(
+                psi, microscope, self.simulation, x_fov, y_fov, offset, self.device
+            )
+
+            # Compute the zero loss and mpl image fraction
+            electron_fraction = elastic_fraction + inelastic_fraction
+
+            # Add the images incoherently and scale the image by the fraction of electrons
+            image = elastic_fraction * image1 + inelastic_fraction * image2
+
+        elif self.simulation["inelastic_model"] == "unfiltered":
+
+            # Compute the energy and spread of the plasmon peak
+            peak, sigma = parakeet.inelastic.most_probable_loss(
+                microscope.beam.energy, shape, angle
+            )  # eV
+            peak = min(peak, 1000 * microscope.beam.energy * 0.1)  # eV
+            spread = sigma * sqrt(2) / (microscope.beam.energy * 1000)  # dE / E
+
+            # Compute the zero loss image
+            image1 = compute_image(
+                psi, microscope, self.simulation, x_fov, y_fov, offset, self.device
+            )
+
+            # Add the energy loss
+            microscope.beam.energy -= peak / 1000  # keV
+
+            # Compute the energy spread of the plasmon peak
+            microscope.beam.energy_spread += spread  # dE / E
             print("Energy: %f keV" % microscope.beam.energy)
             print("Energy spread: %f ppm" % microscope.beam.energy_spread)
 
@@ -1016,7 +1052,7 @@ class OpticsImageSimulator(object):
             )
             peak /= 1000.0
             peak = min(peak, microscope.beam.energy * 0.1)
-            spread = sigma / (microscope.beam.energy * 1000)
+            spread = sigma * sqrt(2) / (microscope.beam.energy * 1000)
 
             # Compute the zero loss image
             image1 = compute_image(
@@ -1112,8 +1148,8 @@ class ImageSimulator(object):
         nx = self.microscope.detector.nx
         ny = self.microscope.detector.ny
         pixel_size = self.microscope.detector.pixel_size
-        x_fov = nx * pixel_size
-        y_fov = ny * pixel_size
+        # x_fov = nx * pixel_size
+        # y_fov = ny * pixel_size
 
         # Get the specimen atoms
         logger.info(f"Simulating image {index+1}")
@@ -1272,8 +1308,8 @@ class SimpleImageSimulator(object):
         # input_multislice.spec_rot_theta = angle
         # input_multislice.spec_rot_u0 = simulation.scan.axis
 
-        x0 = (-offset, -offset)
-        x1 = (x_fov + offset, y_fov + offset)
+        # x0 = (-offset, -offset)
+        # x1 = (x_fov + offset, y_fov + offset)
 
         # Create the multem system configuration
         system_conf = create_system_configuration(self.device)
